Struct ElectionScore
pub struct ElectionScore {
pub minimal_stake: u128,
pub sum_stake: u128,
pub sum_stake_squared: u128,
}Expand description
The score of an election. This is the main measure of an election’s quality.
By definition, the order of significance in ElectionScore is:
minimal_stake.sum_stake.sum_stake_squared.
Fields
minimal_stake: u128The minimal winner, in terms of total backing stake.
This parameter should be maximized.
sum_stake: u128The sum of the total backing of all winners.
This parameter should maximized
sum_stake_squared: u128The sum squared of the total backing of all winners, aka. the variance.
This parameter should be minimized.
Implementations
impl ElectionScore
impl ElectionScore
impl ElectionScore
impl ElectionScore
pub fn strict_threshold_better(
self,
other: ElectionScore,
threshold: impl PerThing,
) -> bool
pub fn strict_threshold_better( self, other: ElectionScore, threshold: impl PerThing, ) -> bool
Compares two sets of election scores based on desirability, returning true if self is
strictly threshold better than other. In other words, each element of self must be
better than other relative to the given threshold.
Evaluation is done based on the order of significance of the fields of ElectionScore.
pub fn strict_better(self, other: ElectionScore) -> bool
pub fn strict_better(self, other: ElectionScore) -> bool
Compares two sets of election scores based on desirability, returning true if self is
strictly better than other.