pub type VoterOf<T> = Voter<<T as MinerConfig>::AccountId, <T as MinerConfig>::MaxVotesPerVoter>;Expand description
Alias for a voter, parameterized by the miner config.
pub type VoterOf<T> = Voter<<T as MinerConfig>::AccountId, <T as MinerConfig>::MaxVotesPerVoter>;Alias for a voter, parameterized by the miner config.