pub trait SignedInterface {
// Required method
fn has_leader(round: u32) -> bool;
}Expand description
Slim interface for the parent pallet to be able to inspect the state of the signed pallet.
Intentionally left different from crate::verifier::SolutionDataProvider, as that is
specialized for communication between verifier <> signed.
Required Methods
Sourcefn has_leader(round: u32) -> bool
fn has_leader(round: u32) -> bool
Returns true if there is a candidate solution to be verified.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.